#[non_exhaustive]pub enum ManifestError {
Magic,
Version,
Truncated,
Utf8,
Hash,
Trailing,
Invalid(&'static str),
}Available on crate feature
manifest only.Expand description
Why a manifest file (manifest.mf2m) or value was rejected.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Magic
Not a manifest file.
Version
A major version this reader does not know.
Truncated
The file ends early, or a varint is malformed.
Utf8
A name is not valid UTF-8.
Hash
The stored hash does not match the content.
Trailing
Bytes after the end of the manifest.
Invalid(&'static str)
A list is not strictly ascending, or the per-message lists do not match the ids.